@@ -28,12 +28,6 @@ confint <- function(object, method, ...)
 #if(!isGeneric("param<-")){ 
 #    setGeneric("param<-", function(object, value) standardGeneric("param<-"))
 #}
-if(!isGeneric("type")){
-    setGeneric("type", function(object) standardGeneric("type"))
-}
-if(!isGeneric("SymmCenter")){
-    setGeneric("SymmCenter", function(object) standardGeneric("SymmCenter"))
-}
 if(!isGeneric("distrSymm")){
     setGeneric("distrSymm", function(object) standardGeneric("distrSymm"))
 }
@@ -62,7 +56,7 @@ if(!isGeneric("nuisance<-")){
     setGeneric("nuisance<-", function(object, value) standardGeneric("nuisance<-"))
 }
 if(!isGeneric("trafo")){
-    setGeneric("trafo", function(object, param) standardGeneric("trafo"))
+    setGeneric("trafo", function(object, param, ...) standardGeneric("trafo"))
 }
 if(!isGeneric("trafo<-")){
     setGeneric("trafo<-", function(object, value) standardGeneric("trafo<-"))
@@ -179,7 +173,7 @@ if(!isGeneric("nuisance.estimate")){
     setGeneric("nuisance.estimate", function(object) standardGeneric("nuisance.estimate"))
 }
 if(!isGeneric("samplesize.estimate")){
-    setGeneric("samplesize.estimate", function(object) standardGeneric("samplesize.estimate"))
+    setGeneric("samplesize.estimate", function(object, ...) standardGeneric("samplesize.estimate"))
 }
 if(!isGeneric("call.estimate")){
     setGeneric("call.estimate", function(object) standardGeneric("call.estimate"))
@@ -187,6 +181,9 @@ if(!isGeneric("call.estimate")){
 if(!isGeneric("fixed.estimate")){
     setGeneric("fixed.estimate", function(object,... ) standardGeneric("fixed.estimate"))
 }
+if(!isGeneric("completecases.estimate")){
+  	     setGeneric("completecases.estimate", function(object) standardGeneric("completecases.estimate"))
+}
 if(!isGeneric("Infos")){
     setGeneric("Infos", function(object) standardGeneric("Infos"))
 }
@@ -202,8 +199,11 @@ if(!isGeneric("criterion")){
 if(!isGeneric("criterion<-")){
     setGeneric("criterion<-", function(object, value) standardGeneric("criterion<-"))
 }
+if(!isGeneric("completecases")){
+  	     setGeneric("completecases", function(object) standardGeneric("completecases"))
+}
 if(!isGeneric("samplesize")){
-    setGeneric("samplesize", function(object) standardGeneric("samplesize"))
+    setGeneric("samplesize", function(object, ...) standardGeneric("samplesize"))
 }
 if(!isGeneric("asvar")){
     setGeneric("asvar", function(object) standardGeneric("asvar"))
@@ -275,3 +275,6 @@ if(!isGeneric("criterion.fct")){
 if(!isGeneric("method")){
     setGeneric("method", function(object) standardGeneric("method"))
 }
+if(!isGeneric("optimwarn")){
+    setGeneric("optimwarn", function(object) standardGeneric("optimwarn"))
+}
